@@ -88,6 +88,8 @@ epilog = """---------- 使用帮助 ----------
     - json: https://docs.python.org/3/library/json.html
     - orjson: https://pypi.org/project/orjson/
     - ujson: https://pypi.org/project/ujson/
+    - msgpack: https://pypi.org/project/msgpack/
+    - avro: https://pypi.org/project/avro/
 
 .. 推荐阅读:
 
